@@ -1,7 +1,6 @@
 #!/usr/bin/python
 # has to be a full import due to Ansible 2.0 compatibility
 from ansible.module_utils.basic import AnsibleModule
-
 from waldur_client import WaldurClientException, waldur_client_from_module
 
 ANSIBLE_METADATA = {
@@ -18,7 +17,7 @@ version_added: 0.1
 description:
   - Get an OpenStack instance
 requirements:
-  - python = 3.6
+  - python = 3.8
   - requests
   - python-waldur-client
 options:
@@ -65,7 +64,8 @@ def main():
     client = waldur_client_from_module(module)
     try:
         instance = client.get_instance_via_marketplace(
-            name=module.params['name'], project=module.params['project'],
+            name=module.params['name'],
+            project=module.params['project'],
         )
     except WaldurClientException as e:
         module.fail_json(msg=str(e))
