@@ -1,7 +1,6 @@
 #!/usr/bin/python
 # has to be a full import due to Ansible 2.0 compatibility
 from ansible.module_utils.basic import AnsibleModule
-
 from waldur_client import (
     ObjectDoesNotExist,
     WaldurClientException,
@@ -23,7 +22,7 @@ version_added: 0.8
 description:
   - Create, update or delete OpenStack compute instance via Waldur API.
 requirements:
-  - python = 3.6
+  - python = 3.8
   - requests
   - python-waldur-client
 options:
@@ -370,6 +369,7 @@ def send_request_to_waldur(client, module):
                 image=module.params['image'],
                 system_volume_size=module.params['system_volume_size'],
                 security_groups=module.params.get('security_groups'),
+                server_group=module.params.get('server_group'),
                 flavor=module.params.get('flavor'),
                 flavor_min_cpu=module.params.get('flavor_min_cpu'),
                 flavor_min_ram=module.params.get('flavor_min_ram'),
@@ -404,6 +404,7 @@ def main():
             offering=dict(type='str', default=None),
             release_floating_ips=dict(type='bool', default=True),
             security_groups=dict(type='list', default=None),
+            server_group=dict(type='str', default=None),
             ssh_key=dict(type='str', default=None),
             subnet=dict(type='list', default=None),
             system_volume_size=dict(type='int', default=None),
