@@ -1,7 +1,6 @@
 #!/usr/bin/python
 # has to be a full import due to Ansible 2.0 compatibility
 from ansible.module_utils.basic import AnsibleModule
-
 from waldur_client import (
     WaldurClientException,
     waldur_client_from_module,
@@ -20,7 +19,7 @@ module: waldur_os_floating_ip
 short_description: Assign floating IPs
 version_added: 0.1
 requirements:
-  - "python = 3.6"
+  - "python = 3.8"
   - "requests"
   - "python-waldur-client"
 options:
@@ -110,7 +109,10 @@ def main():
 
     client = waldur_client_from_module(module)
     floating_ips = module.params.get('floating_ips') or [
-        {'address': module.params['address'], 'subnet': module.params['subnet'],}
+        {
+            'address': module.params['address'],
+            'subnet': module.params['subnet'],
+        }
     ]
     instance = module.params['instance']
 
