@@ -3,7 +3,6 @@
 from ipaddress import AddressValueError, IPv4Interface, IPv6Interface, NetmaskValueError
 
 from ansible.module_utils.basic import AnsibleModule
-
 from waldur_client import (
     WaldurClientException,
     waldur_client_from_module,
@@ -24,7 +23,7 @@ version_added: 0.1
 description:
   - "Add/Update/Remove OpenStack tenant security group"
 requirements:
-  - "python = 3.6"
+  - "python = 3.8"
   - "requests"
   - "python-waldur-client"
 options:
@@ -400,7 +399,9 @@ def main():
         project=dict(type='str', required=False),
         tenant=dict(type='str', required=True),
     )
-    module = AnsibleModule(argument_spec=fields,)
+    module = AnsibleModule(
+        argument_spec=fields,
+    )
 
     client = waldur_client_from_module(module)
 
